@@ -10,7 +10,7 @@ import numpy as np
 
 
 def list_to_chromagram(note_list, num_frames, frame_rate):
-    """Create a chromagram matrix from a list of note events
+    """Create a chromagram matrix as np.ndarray from a list of note events.
 
     Args:
         note_list (list): A list of note events (e.g. gathered from a CSV file by
@@ -30,7 +30,7 @@ def list_to_chromagram(note_list, num_frames, frame_rate):
 
 
 def generate_shepard_tone(chromaNum, Fs, N, weight=1, Fc=440, sigma=15, phase=0):
-    """Generates shepard tone
+    """Generate a shepard tone signal as np.ndarray.
 
     Args:
         chromaNum (int): 1=C,...
@@ -47,7 +47,7 @@ def generate_shepard_tone(chromaNum, Fs, N, weight=1, Fc=440, sigma=15, phase=0)
     tone = np.zeros(N)
     # Envelope function for Shepard tones
     p = 24 + chromaNum
-    if(p > 32):
+    if p > 32:
         p = p - 12
     while p < 108:
         scale_factor = 1 / (np.sqrt(2 * np.pi) * sigma)
@@ -61,7 +61,7 @@ def generate_shepard_tone(chromaNum, Fs, N, weight=1, Fc=440, sigma=15, phase=0)
 
 
 def sonify_chromagram(chroma_data, N, frame_rate, Fs, fading_msec=5):
-    """Sonify the chroma features from a chromagram
+    """Generate a sonification of the chroma features from a chromagram matrix using shepard tones.
 
     Args:
         chroma_data (np.ndarray): A chromagram (e.g., gathered from a list of note events by
@@ -102,7 +102,8 @@ def sonify_chromagram(chroma_data, N, frame_rate, Fs, fading_msec=5):
 
 
 def sonify_chromagram_with_signal(chroma_data, x, frame_rate, Fs, fading_msec=5, stereo=True):
-    """Sonify the chroma features from a chromagram together with a corresponding signal
+    """Sonifiy the chroma features from a chromagram matrix (using :func:`libfmp.b.b_sonification.sonify_chromagram`)
+    together with a corresponding signal.
 
     Args:
         chroma_data (np.ndarray): A chromagram (e.g., gathered from a list of note events by
@@ -134,7 +135,7 @@ def sonify_chromagram_with_signal(chroma_data, x, frame_rate, Fs, fading_msec=5,
 
 
 def list_to_pitch_activations(note_list, num_frames, frame_rate):
-    """Create a pitch activation matrix from a list of note events
+    """Create a pitch activation matrix from a list of note events.
 
     Args:
         note_list (list): A list of note events (e.g., gathered from a CSV file by
@@ -158,7 +159,7 @@ def list_to_pitch_activations(note_list, num_frames, frame_rate):
 
 
 def sonify_pitch_activations(P, N, frame_rate, Fs, min_pitch=1, Fc=440, harmonics_weights=[1], fading_msec=5):
-    """Sonify the pitches from a pitch activation matrix
+    """Sonify the pitches from a pitch activation matrix using sinusoidals.
 
     Args:
         P (np.ndarray): A pitch activation matrix (e.g., gathered from a list of note events by
@@ -186,8 +187,9 @@ def sonify_pitch_activations(P, N, frame_rate, Fs, min_pitch=1, Fc=440, harmonic
             pitch = min_pitch + p
             freq = (2 ** ((pitch - 69) / 12)) * Fc
             sin_tone = np.zeros((N,))
-            for i in range(len(harmonics_weights)):
-                sin_tone += harmonics_weights[i] * np.sin(2 * np.pi * (i+1) * freq * np.arange(N) / Fs)
+
+            for i, cur_harmonic_weight in enumerate(harmonics_weights):
+                sin_tone += cur_harmonic_weight * np.sin(2 * np.pi * (i+1) * freq * np.arange(N) / Fs)
 
             weights = np.zeros((N,))
             for n in range(P.shape[1]):
@@ -209,7 +211,8 @@ def sonify_pitch_activations(P, N, frame_rate, Fs, min_pitch=1, Fc=440, harmonic
 
 def sonify_pitch_activations_with_signal(P, x, frame_rate, Fs, min_pitch=1, Fc=440, harmonics_weights=[1],
                                          fading_msec=5, stereo=True):
-    """Sonify the pitches from a pitch activation matrix together with a corresponding signal
+    """Sonify the pitches from a pitch activation matrix (using
+    :func:`libfmp.b.b_sonification.sonify_pitch_activations`) together with a corresponding signal.
 
     Args:
         P (np.ndarray): A pitch activation matrix (e.g., gathered from a list of note events by
