@@ -120,7 +120,8 @@ def xml_to_list(xml):
 
 
 def list_to_csv(score, fn_out):
-    """Convert a list of note events to a csv file
+    """Write a list of note events (comprising a start time, duration, pitch, velocity, and label for each note event)
+    to a CSV file
 
     Args:
         score (list): List of note events
@@ -169,6 +170,8 @@ def visualize_piano_roll(score, xlabel='Time (seconds)', ylabel='Pitch', colors=
     time_max = max(note[0] + note[1] for note in score)
 
     for start, duration, pitch, velocity, label in score:
+        if velocity_alpha is False:
+            velocity = None
         rect = patches.Rectangle((start, pitch - 0.5), duration, 1, linewidth=1,
                                  edgecolor='k', facecolor=colors[label], alpha=velocity)
         ax.add_patch(rect)
