@@ -11,13 +11,20 @@ from matplotlib import pyplot as plt
 
 def generate_figure(figsize=(2, 2), xlim=[0, 1], ylim=[0, 1]):
     """Generate figure for plotting complex numbers
-       Notebook: C2/C2_ComplexNumbers.ipynb"""
+
+    Notebook: C2/C2_ComplexNumbers.ipynb
+
+    Args:
+        figsize: Figure size (Default value = (2, 2))
+        xlim: Limits of x-axis (Default value = [0, 1])
+        ylim: Limits of y-axis (Default value = [0, 1])
+    """
     plt.figure(figsize=figsize)
     plt.grid()
     plt.xlim(xlim)
     plt.ylim(ylim)
-    plt.xlabel('$\mathrm{Re}$')
-    plt.ylabel('$\mathrm{Im}$')
+    plt.xlabel(r'$\mathrm{Re}$')
+    plt.ylabel(r'$\mathrm{Im}$')
 
 
 def plot_vector(c, color='k', start=0, linestyle='-'):
@@ -27,12 +34,12 @@ def plot_vector(c, color='k', start=0, linestyle='-'):
 
     Args:
         c: Complex number
-        color: Color of arrow
-        start: Complex number encoding the start position
-        linestyle: Linestyle of arrow
+        color: Color of arrow (Default value = 'k')
+        start: Complex number encoding the start position (Default value = 0)
+        linestyle: Linestyle of arrow (Default value = '-')
 
     Returns:
-        plt.arrow: matplotlib.patches.FancyArrow
+        arrow (matplotlib.patches.FancyArrow): Arrow
     """
     return plt.arrow(np.real(start), np.imag(start), np.real(c), np.imag(c),
                      linestyle=linestyle, head_width=0.05, fc=color, ec=color, overhang=0.3,
