@@ -52,7 +52,7 @@ def compute_novelty_energy(x, Fs=1, N=2048, H=128, gamma=10.0, norm=True):
         x (np.ndarray): Signal
         Fs (scalar): Sampling rate (Default value = 1)
         N (int): Window size (Default value = 2048)
-        H (int): Hope size (Default value = 128)
+        H (int): Hop size (Default value = 128)
         gamma (float): Parameter for logarithmic compression (Default value = 10.0)
         norm (bool): Apply max norm (if norm==True) (Default value = True)
 
@@ -109,7 +109,7 @@ def compute_novelty_spectrum(x, Fs=1, N=1024, H=256, gamma=100.0, M=10, norm=Tru
         x (np.ndarray): Signal
         Fs (scalar): Sampling rate (Default value = 1)
         N (int): Window size (Default value = 1024)
-        H (int): Hope size (Default value = 256)
+        H (int): Hop size (Default value = 256)
         gamma (float): Parameter for logarithmic compression (Default value = 100.0)
         M (int): Size (frames) of local average (Default value = 10)
         norm (bool): Apply max norm (if norm==True) (Default value = True)
@@ -297,5 +297,5 @@ def average_nov_dic(nov_dic, time_max_sec, Fs_out=100, norm=True, sigma=None):
         max_value = np.max(nov_average)
         if max_value > 0:
             nov_average = nov_average / max_value
-    nov_matrix[k+1, :] = nov_average
+    nov_matrix[nov_num, :] = nov_average
     return nov_matrix, Fs_out
